Package: plumbertableau
Type: Package
Title: Turn 'Plumber' APIs into 'Tableau' Extensions
Version: 0.1.1
Authors@R: c(
    person("James", "Blair", email = "james@rstudio.com", role = c("aut", "cre")),
    person("Joe", "Cheng", email = "joe@rstudio.com", role = c("aut")),
    person("Toph", "Allen", email = "toph@rstudio.com", role = "aut"),
    person("Bill", "Sager", email = "bill.sager@rstudio.com", role = "aut"),
    person("RStudio", role = c("cph", "fnd")),
    person("Tableau", role = c("cph"))
    )
Description: Build 'Plumber' APIs that can be used in 'Tableau' workbooks.
    Annotations in R comments allow APIs to conform to the 'Tableau Analytics
    Extension' specification, so that R code can be used to power 'Tableau'
    workbooks.
License: MIT + file LICENSE
URL: https://rstudio.github.io/plumbertableau/,
        https://github.com/rstudio/plumbertableau
BugReports: https://github.com/rstudio/plumbertableau/issues
Encoding: UTF-8
Depends: R (>= 3.0.0)
Imports: plumber (>= 1.1.0), magrittr, curl, httpuv, jsonlite, later,
        promises, rlang, htmltools, debugme, stringi, markdown,
        urltools, utils, httr, knitr
RoxygenNote: 7.1.1
Suggests: testthat (>= 3.0.0), rmarkdown, covr
Config/testthat/edition: 3
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2023-12-15 18:32:07 UTC; yihui
Author: James Blair [aut, cre],
  Joe Cheng [aut],
  Toph Allen [aut],
  Bill Sager [aut],
  RStudio [cph, fnd],
  Tableau [cph]
Maintainer: James Blair <james@rstudio.com>
Repository: CRAN
Date/Publication: 2023-12-19 02:20:03 UTC
Built: R 4.6.0; ; 2026-04-28 08:34:18 UTC; unix
