# Generated by roxygen2: do not edit by hand

export("%>%")
export(arg_spec)
export(mock_tableau_request)
export(return_spec)
export(tableau_extension)
export(tableau_handler)
export(tableau_invoke)
import(stringi)
importFrom(htmltools,tags)
importFrom(magrittr,"%>%")
importFrom(stats,setNames)
